LoadMoreUiBuilder<T extends Object> class

Inheritance

Constructors

LoadMoreUiBuilder({required String? url, Key? key, ScrollController? scrollController, Axis scrollDirection = Axis.vertical, ChildWidget<T>? childWidget, bool isFirstLoad = true, Map<String, dynamic> map = const {}, Widget? scrollHeaderWidget, bool? isList = true, ReqType requestType = ReqType.get, Widget? loadingWidget, int gridCount = 2, SuccessCallback? successCallback, CustomMoreCallback? customMoreCallback, CustomErrorCallback? customErrorCallback, double gridChildRatio = 100 / 130, CustomMoreWidget? customMoreWidget, double crossAxisSpacing = 0, double mainAxisSpacing = 0, bool enablePullUp = false, bool? isCached = false, Widget? noDataWidget, bool isNotShowSnack = false, bool isSliver = false, double? mainAxisExt})
LoadMoreUiBuilder.init({required String? url, Key? key, ScrollController? scrollController, ChildWidget<T>? childWidget, bool isFirstLoad = true, Map<String, dynamic> map = const {}, Widget? scrollHeaderWidget, bool? isList = true, ReqType requestType = ReqType.get, Widget? loadingWidget, int gridCount = 2, SuccessCallback? successCallback, CustomMoreCallback? customMoreCallback, CustomErrorCallback? customErrorCallback, double gridChildRatio = 100 / 130, double? mainAxisExt, CustomMoreWidget? customMoreWidget, bool enablePullUp = false, bool? isCached = false, bool isNotShowSnack = false, Widget? noDataWidget, Axis scrollDirection = Axis.vertical, double crossAxisSpacing = 0, double mainAxisSpacing = 0, bool isSliver = false})

Properties

childWidget ChildWidget<T>?
final
crossAxisSpacing double
final
customErrorCallback → CustomErrorCallback?
final
customMoreCallback → CustomMoreCallback?
final
customMoreWidget CustomMoreWidget?
final
enablePullUp bool
final
gridChildRatio double
final
gridCount int
final
hashCode int
The hash code for this object.
no setterinherited
isCached bool?
final
isFirstLoad bool
latefinal
isList bool?
final
isNotShowSnack bool
final
isSliver bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingWidget Widget?
final
mainAxisExt double?
final
mainAxisSpacing double
final
map Map<String, dynamic>
latefinal
noDataWidget Widget?
final
requestType ReqType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController?
final
scrollDirection Axis
final
scrollHeaderWidget Widget?
final
successCallback → SuccessCallback?
final
url String?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() LoadMoreUiBuilderState<T>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited