SharedPrefsStorage class

Implemented types

Constructors

SharedPrefsStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getString(String key) Future<String?>
Retrieves a string value for the given key.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) Future<void>
Removes the value associated with the given key.
override
setString(String key, String value) Future<void>
Sets a string value for the given key.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited